==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2015/11/16 16:20:12                                            */
/****************************************************************************/
CREATE TABLE GF05 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                        /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR (    9 )        DEFAULT '0'                     /*  80 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /*  90 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                        /* 100 ﾉｯﾄﾇﾙ        */
 , FGCOM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 110 共通項目F    */
 , RENDERER     VARCHAR (   10 )                                        /* 120 表示種別     */
 , EDITOR       VARCHAR (   10 )                                        /* 130 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                        /* 140 文字種別     */
 , BIKO         VARCHAR ( 2000 )                                        /* 150 備考         */
 , CDKH         VARCHAR (    1 )                                        /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

CREATE SEQUENCE GF05S00 ;

CREATE TRIGGER GF05T00 FOR GF05
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF05S00,1 );
  END;

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/firebird/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2016/01/07 17:07:25                                            */
/****************************************************************************/
CREATE TABLE GF05 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (    1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   VARCHAR (   50 )                    NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR (   30 )                    NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      VARCHAR (  200 )                                        /*  60 名称         */
 , CLS_NAME     VARCHAR (   10 )                    NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR (    9 )        DEFAULT '0'                     /*  80 使用桁数     */
 , DATA_DEFAULT VARCHAR (  200 )                                        /*  90 初期値       */
 , NOT_NULL     VARCHAR (    1 )                                        /* 100 ﾉｯﾄﾇﾙ        */
 , KBCLM        VARCHAR (    1 )        DEFAULT '0' NOT NULL            /* 120 ｶﾗﾑ区分      */
 , RENDERER     VARCHAR (   10 )                                        /* 130 表示種別     */
 , EDITOR       VARCHAR (   10 )                                        /* 140 編集種別     */
 , DBTYPE       VARCHAR (   10 )                                        /* 150 文字種別     */
 , BIKO         VARCHAR ( 2000 )                                        /* 160 備考         */
 , CDKH         VARCHAR (    1 )                                        /* 170 改廃ｺｰﾄﾞ     */
 , UNIQ         BIGINT                              NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR (   14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                        /* 890 更新者       */
);

CREATE SEQUENCE GF05S00 ;

CREATE TRIGGER GF05T00 FOR GF05
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GF05S00,1 );
  END;
